Package: NGLVieweR
Title: Interactive 3D Visualization of Molecular Structures
Version: 1.4.0
Authors@R: c( 
    person("Niels", "van der Velden", role = c("aut", "cre"), email = "n.s.j.vandervelden@gmail.com"),
    person("Alexander", "Rose", role = "cph", comment = 'NGL.js library'))
Maintainer: Niels van der Velden <n.s.j.vandervelden@gmail.com>
Description: Provides an 'htmlwidgets' <https://www.htmlwidgets.org/> interface to 'NGL.js' <http://nglviewer.org/ngl/api/>.
    'NGLvieweR' can be used to visualize and interact with protein databank ('PDB') and structural files in R and Shiny applications.
    It includes a set of API functions to manipulate the viewer after creation in Shiny.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
Imports: htmlwidgets, magrittr, tools, shiny
Suggests: knitr, webshot, markdown, rmarkdown, colourpicker
VignetteBuilder: knitr
URL: https://github.com/nvelden/NGLVieweR
BugReports: https://github.com/nvelden/NGLVieweR/issues
NeedsCompilation: no
Packaged: 2024-11-22 18:57:06 UTC; nielsvandervelden
Author: Niels van der Velden [aut, cre],
  Alexander Rose [cph] (NGL.js library)
Repository: CRAN
Date/Publication: 2024-11-22 19:10:02 UTC
Built: R 4.6.0; ; 2026-04-26 20:05:45 UTC; unix
