# Generated by roxygen2: do not edit by hand

export("%>%")
export(NGLVieweR)
export(NGLVieweROutput)
export(NGLVieweR_example)
export(NGLVieweR_proxy)
export(addRepresentation)
export(addSelection)
export(addStructure)
export(file_ext)
export(removeSelection)
export(renderNGLVieweR)
export(selectionParameters)
export(setFocus)
export(setPosition)
export(setQuality)
export(setRock)
export(setRotation)
export(setScale)
export(setSpin)
export(setSuperpose)
export(snapShot)
export(stageParameters)
export(updateColor)
export(updateFocus)
export(updateFullscreen)
export(updateRepresentation)
export(updateRock)
export(updateSelection)
export(updateSpin)
export(updateStage)
export(updateVisibility)
export(updateZoomMove)
export(zoomMove)
importFrom(htmlwidgets,createWidget)
importFrom(htmlwidgets,shinyRenderWidget)
importFrom(htmlwidgets,shinyWidgetOutput)
importFrom(magrittr,"%>%")
importFrom(shiny,shinyAppDir)
importFrom(tools,file_ext)
